"use client";

import { motion, Variants } from "framer-motion";
import { ReactNode, useRef } from "react";
import { useInView } from "framer-motion";

interface MotionWrapperProps {
  children: ReactNode;
  delay?: number;
}

const MotionWrapper: React.FC<MotionWrapperProps> = ({
  children,
  delay = 0,
}) => {
  const ref = useRef<HTMLDivElement>(null); // Reference to a <div> element
  const isInView = useInView(ref, { once: false }); // Trigger animation only once when in view

  const variants: Variants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: {
        duration: 1.0,
        delay,
        ease: "easeOut",
      },
    },
  };

  return (
    <motion.div
      ref={ref} // Pass the ref to motion.div
      initial="hidden"
      animate={isInView ? "visible" : "hidden"}
      variants={variants}
    >
      {children}
    </motion.div>
  );
};

export default MotionWrapper;
